<?php
/*
Plugin Name: Featured Comment Widget
Plugin URI: http://pancaketheorem.com/featured-comment-widget
Description: A widget that allows you to showcase any comment that has been published on your site. All you need to do is enter the comment's ID in the widget form.
Version: 1.0
Author: Jenn Schiffer
Author URI: http://jennschiffer.com

Copyright 2011  Jenn Schiffer  (http://jennschiffer.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

function featuredCommentWidget_init() {
	register_widget('featuredCommentWidget');
}

add_action('init', 'featuredCommentWidget_init', 1);

function featuredCommentCSS() {
	echo '<style type="text/css">
			.featuredComment-comment { margin: 3px auto 5px;}
			.featuredComment-cite { display: block; text-align: left; line-height: 1em;}
			.featuredComment-cite:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
				.featuredComment-gravatar {float: right; padding: 0px 5px;}
				.featuredComment-author {float: right;}
		  </style>';
}

add_action('wp_head', 'featuredCommentCSS');

class featuredCommentWidget extends WP_Widget {

	function featuredCommentWidget() {
		$widget_ops = array('classname' => 'featured_comment_widget', 'description' => __('Enter a comment&apos;s ID to feature it on your sidebar.'));
		$this->WP_Widget('featuredComment', __('Featured Comment'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$commentID = apply_filters( 'widget_commentID', empty($instance['commentID']) ? '2' : $instance['commentID'], $instance, $this->id_base);
		$gravatarSize = apply_filters( 'widget_gravatarSize', empty($instance['gravatarSize']) ? '25' : $instance['gravatarSize'], $instance, $this->id_base);
		
		echo $before_widget;
		if ( !empty( $commentID ) ) { echo $before_title . 'Featured Comment' . $after_title; } ?>
			<?php 
				$featuredComment = get_comment($commentID);
				$featuredCommentName = $featuredComment->comment_author;
				$featuredCommentEmail = $featuredComment->comment_author_email;
				$featuredCommentContent = $featuredComment->comment_content;
				$featuredCommentPostID = $featuredComment->comment_post_ID;
				$featuredCommentURL = '/?p='.$featuredCommentPostID.'/#comment-'.$commentID;
			
				echo '<div class="featuredComment-comment">'. $featuredCommentContent . '</div>';
			?>
			
				<div class="featuredComment-cite">
					<span class="featuredComment-author"><a href="<?php echo $featuredCommentURL; ?>">Posted by <br /><?php echo $featuredCommentName; ?></a></span>
					<span class="featuredComment-gravatar"><a href="<?php echo $featuredCommentURL; ?>"><?php echo get_avatar($featuredCommentEmail, $gravatarSize); ?></a></span>
				</div>
			
	<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['commentID'] = strip_tags($new_instance['commentID']);
		$instance['gravatarSize'] = strip_tags($new_instance['gravatarSize']);
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'commentID' => '', 'gravatarSize' => '') );
		$commentID = strip_tags($instance['commentID']);
		$gravatarSize = strip_tags($instance['gravatarSize']);
	?>
	
		<p><label for="<?php echo $this->get_field_id('commentID'); ?>"><?php _e('Comment ID:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('commentID'); ?>" name="<?php echo $this->get_field_name('commentID'); ?>" type="text" value="<?php echo esc_attr($commentID); ?>" /></p>
		<p><label for="<?php echo $this->get_field_id('gravatarSize'); ?>"><?php _e('Gravatar width in pixels<br />(<em>leaving blank defaults to 25</em>):'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('gravatarSize'); ?>" name="<?php echo $this->get_field_name('gravatarSize'); ?>" type="text" value="<?php echo esc_attr($gravatarSize); ?>" /></p>
		
	<?php
	}
}
?>